==> haskell-path-0.6.1-10-i686.pkg.tar.xz: usr/share/haskell/register/haskell-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path
version: 0.6.1
id: path-0.6.1-3vYPgWREPZf5twNYNrl9DA
key: path-0.6.1-3vYPgWREPZf5twNYNrl9DA
license: BSD3
copyright: 2015–2017 FP Complete
maintainer: Chris Done <chrisdone@fpcomplete.com>
synopsis: Support for well-typed paths
description:
    Support for well-typed paths.
category: System, Filesystem
author: Chris Done <chrisdone@fpcomplete.com>
exposed: True
indefinite: False
exposed-modules:
    Path Path.Internal
abi: 50d28c00d8ec595b7cd99f1f1359efd5
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/path-0.6.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/path-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/path-0.6.1
hs-libraries: HSpath-0.6.1-3vYPgWREPZf5twNYNrl9DA
depends:
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y base-4.10.0.0 deepseq-1.4.3.0
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6 filepath-1.4.1.2
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk template-haskell-2.12.0.0
abi-depends: aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=e190029673d5410544b32623a0e81f5f
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=c277093fa16e707f51e09b45510f1326
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
haddock-interfaces: /usr/share/doc/haskell-path/html/path.haddock
haddock-html: /usr/share/doc/haskell-path/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-0.6.1-11-i686.pkg.tar.xz: usr/share/haskell/register/haskell-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path
version: 0.6.1
id: path-0.6.1-F7dXkjr3RauIWw3mbJNf6I
key: path-0.6.1-F7dXkjr3RauIWw3mbJNf6I
license: BSD3
copyright: 2015–2017 FP Complete
maintainer: Chris Done <chrisdone@fpcomplete.com>
synopsis: Support for well-typed paths
description:
    Support for well-typed paths.
category: System, Filesystem
author: Chris Done <chrisdone@fpcomplete.com>
exposed: True
indefinite: False
exposed-modules:
    Path Path.Internal
abi: 136a60c7b317ab86a1b8f634a41e99c5
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/path-0.6.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/path-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/path-0.6.1
hs-libraries: HSpath-0.6.1-F7dXkjr3RauIWw3mbJNf6I
depends:
    aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq base-4.10.0.0 deepseq-1.4.3.0
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6 filepath-1.4.1.2
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk template-haskell-2.12.0.0
abi-depends: aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=8b90ef7c46d906c8047345fb433e32fe
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=e190029673d5410544b32623a0e81f5f
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=c277093fa16e707f51e09b45510f1326
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
haddock-interfaces: /usr/share/doc/haskell-path/html/path.haddock
haddock-html: /usr/share/doc/haskell-path/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
